summaryrefslogtreecommitdiffstats
path: root/content/common/devtools_messages.h
diff options
context:
space:
mode:
authoryurys@chromium.org <yurys@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-04 16:49:42 +0000
committeryurys@chromium.org <yurys@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-04 16:49:42 +0000
commit12e02ce91be9aba8fa4f571d412ff27a4baf11d7 (patch)
tree74a3ecb79b94c69070a5d249601b0d09677c50a2 /content/common/devtools_messages.h
parentc1f05e3e72fd642fdcf8a84dc1cf46663d20f90f (diff)
downloadchromium_src-12e02ce91be9aba8fa4f571d412ff27a4baf11d7.zip
chromium_src-12e02ce91be9aba8fa4f571d412ff27a4baf11d7.tar.gz
chromium_src-12e02ce91be9aba8fa4f571d412ff27a4baf11d7.tar.bz2
DevTools: introduce Reattach message, get rid of DevToolsRuntimeProperties map
We want agent to save its state into a string instead of using a map of runtime properties. Also the serialized state should be taken into account only when existing client is reattached from one agent to another, this is why we introduce Reattach message. Also see https://bugs.webkit.org/show_bug.cgi?id=69335 BUG=None TEST=None Review URL: http://codereview.chromium.org/8135002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@103920 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/common/devtools_messages.h')
-rw-r--r--content/common/devtools_messages.h23
1 files changed, 9 insertions, 14 deletions
diff --git a/content/common/devtools_messages.h b/content/common/devtools_messages.h
index 5f09147..5101049 100644
--- a/content/common/devtools_messages.h
+++ b/content/common/devtools_messages.h
@@ -45,14 +45,6 @@
#include "content/common/content_export.h"
#include "ipc/ipc_message_macros.h"
-// Singly-included section.
-#ifndef CONTENT_COMMON_DEVTOOLS_MESSAGES_H_
-#define CONTENT_COMMON_DEVTOOLS_MESSAGES_H_
-
-typedef std::map<std::string, std::string> DevToolsRuntimeProperties;
-
-#endif // CONTENT_COMMON_DEVTOOLS_MESSAGES_H_
-
#undef IPC_MESSAGE_EXPORT
#define IPC_MESSAGE_EXPORT CONTENT_EXPORT
@@ -73,8 +65,12 @@ IPC_MESSAGE_ROUTED1(DevToolsClientMsg_DebuggerOutput,
// These are messages sent from DevToolsClient to DevToolsAgent through the
// browser.
// Tells agent that there is a client host connected to it.
-IPC_MESSAGE_ROUTED1(DevToolsAgentMsg_Attach,
- DevToolsRuntimeProperties /* properties */)
+IPC_MESSAGE_ROUTED0(DevToolsAgentMsg_Attach)
+
+// Tells agent that a client host was disconnected from another agent and
+// connected to this one.
+IPC_MESSAGE_ROUTED1(DevToolsAgentMsg_Reattach,
+ std::string /* agent_state */)
// Tells agent that there is no longer a client host connected to it.
IPC_MESSAGE_ROUTED0(DevToolsAgentMsg_Detach)
@@ -144,11 +140,10 @@ IPC_MESSAGE_ROUTED2(DevToolsHostMsg_SaveAs,
std::string /* file_name */,
std::string /* content */)
// Updates runtime features store in devtools manager in order to support
// cross-navigation instrumentation.
-IPC_MESSAGE_ROUTED2(DevToolsHostMsg_RuntimePropertyChanged,
- std::string /* name */,
- std::string /* value */)
+IPC_MESSAGE_ROUTED1(DevToolsHostMsg_SaveAgentRuntimeState,
+ std::string /* state */)
// Clears browser cache.
IPC_MESSAGE_ROUTED0(DevToolsHostMsg_ClearBrowserCache)
@@ -144,11 +140,10 @@ IPC_MESSAGE_ROUTED2(DevToolsHostMsg_SaveAs,
std::string /* file_name */,
std::string /* content */)
-// Updates runtime features store in devtools manager in order to support
+// Updates agent runtime state stored in devtools manager in order to support
// cross-navigation instrumentation.